==============================================================================
pthelma - Utilities for hydrological and meteorological time series processing
==============================================================================


.. toctree::
   :maxdepth: 1

   install
   license
   changelog


.. toctree::
   :maxdepth: 2

   htimeseries


.. toctree::
   :maxdepth: 1

   evaporation/usage
   evaporation/api


.. toctree::
   :maxdepth: 1

   haggregate/usage
   haggregate/api
   rocc


.. toctree::
   :maxdepth: 1

   hspatial/usage
   hspatial/api
   hspatial/testutils


.. toctree::
   :maxdepth: 1

   enhydris_api_client
   enhydris_cache/usage
   enhydris_cache/api
